#ifndef SHUFFLE_WAKA_H
#define SHUFFLE_WAKA_H

/*!
  \file
  \brief a̕т̃VbtNX

  \author Satofumi KAMIMURA

  $Id$
*/

#include "TypingMode.h"
#include <memory>
#include <vector>


/*!
  \brief a̕т̃Vbt
*/
class ShuffleWaka {
  ShuffleWaka(void);
  ShuffleWaka(const ShuffleWaka& rhs);
  ShuffleWaka& operator = (const ShuffleWaka& rhs);

  struct pImpl;
  const std::auto_ptr<pImpl> pimpl;

public:
  enum {
    NoShuffleSeed = -1,
  };

  /*!
    \brief _V[hw̃RXgN^

    \param seed [i] _V[h

    \attention seed  NoShuffleSeed w肷Ƙâ̕тꊷȂ
  */
  ShuffleWaka(TypingMode mode, int seed);
  ~ShuffleWaka(void);

  /*!
    \brief â̋ړ

    no Ŏw肳ꂽâArange_to ܂ł̈ʒuɋIɈړ

    \param no [i] a̔ԍ
    \param range_to [i] zu͈
  */
  void setSomeWaka(int no, int range_to);

  /*!
    \brief ẫVbt
  */
  void shuffle(std::vector<int>& waka);

  /*!
    \brief ܂莚̃O[v擾

    \param no [i] â̔ԍ
  */
  std::vector<int> getKimarijiGroup(int no);
};

#endif /* !SHUFFLE_WAKA_H */
